<?php

namespace Drupal\pagedesigner_link\Plugin\pagedesigner\Handler;

use Drupal\Core\Url;
use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner\Plugin\PlainFieldHandlerBase;

/**
 * Process entities of type "link".
 *
 * @PagedesignerHandler(
 *   id = "link",
 *   name = @Translation("Link handler"),
 *   types = {
 *      "link",
 *      "href",
 *   },
 * )
 */
class Link extends PlainFieldHandlerBase {

  /**
   * {@inheritdoc}
   */
  public function collectAttachments(array &$attachments) {
    $attachments['library'][] = 'pagedesigner_link/pagedesigner';
  }

  /**
   * {@inheritdoc}
   */
  public function serialize(Element $entity, array &$result = []) {
    $data = [
      'uri' => $entity->field_link->uri,
      'title' => $entity->field_link->title,
    ];
    $result = $data + $result;
  }

  /**
   * {@inheritdoc}
   */
  public function get(Element $entity, string &$result = '') {
    $uri = $entity->field_link->uri;
    if (strpos($entity->field_link->uri, '/') === 0 && preg_match('/\/media\/[0-9]+/', $entity->field_link->uri)) {
      $params = Url::fromUri("internal:" . $entity->field_link->uri)->getRouteParameters();
      $entity_type = key($params);
      if ($entity_type != NULL && !empty($entity_type)) {
        $targetEntity = \Drupal::entityTypeManager()->getStorage($entity_type)->load($params[$entity_type]);
        $source = $targetEntity->getSource();
        $config = $source->getConfiguration();
        $field = $config['source_field'];
        $file = $targetEntity->{$field}->entity;
        if ($file == NULL) {
          $uri = $entity->toUrl('canonical')->toString(TRUE);
        }
        else {
          $uri = file_create_url($file->getFileUri());
        }
        if (empty($uri)) {
          $uri = $entity->toUrl('canonical')->toString(TRUE);
        }
      }
    }
    $result = $uri;
  }

  /**
   * {@inheritdoc}
   */
  public function getContent(Element $entity, array &$list = []) {

  }

  /**
   * {@inheritdoc}
   */
  public function patch(Element $entity, array $data) {
    if (!empty($data['uri'])) {
      $entity->field_link->uri = $data['uri'];
      $entity->field_link->title = $data['title'];
      $entity->saveEdit();
    }
  }

  /**
   * {@inheritdoc}
   */
  public function generate($definition, array $data, Element &$entity = NULL) {
    parent::generate(['type' => 'link', 'name' => 'link'], $data, $entity);
  }

}
