<?php

namespace Drupal\pagedesigner\EventSubscriber;

use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\Core\Session\AccountProxyInterface;

/**
 * Event subscriber to disable css and js aggregation in editing mode.
 *
 * In editing mode, the pagedesigner needs to
 * selectively load javascript and css. Aggregation would prevent this.
 */
class InitSubscriber implements EventSubscriberInterface {

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $user = NULL;

  /**
   * Create the InitSubscriber.
   *
   * @param \Drupal\Core\Session\AccountProxyInterface $user
   *   The current user.
   */
  public function __construct(AccountProxyInterface $user) {
    $this->user = $user;
  }

  /**
   * Disable aggregation in pagedesigner editing mode.
   *
   * @param \Symfony\Component\HttpKernel\Event\GetResponseEvent $event
   *   The event.
   */
  public function disableAggregation(GetResponseEvent $event) {
    global $config;
    $editMode = \Drupal::request()->query->get('pd');
    if (!$this->user->isAnonymous() && $editMode == 1) {
      $config['system.performance']['css']['preprocess'] = FALSE;
      $config['system.performance']['js']['preprocess'] = FALSE;
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      KernelEvents::REQUEST => ['disableAggregation', 255],
    ];
  }

}
